@@ -19,6 +19,7 @@ class SpecterRunner(object):
         self.collector = ConsoleReporter()
         self.arg_parser = ArgumentParser(description=self.DESCRIPTION)
         self.setup_argparse()
+        self.suites = []
 
     def setup_argparse(self):
         self.arg_parser.add_argument(
@@ -35,6 +36,11 @@ class SpecterRunner(object):
             help=_('Selects a module path to run. '
                    'Ex: spec.sample.TestClass'),
             default=None)
+        self.arg_parser.add_argument(
+            '--select-by-metadata', dest='select_meta',
+            help=_('Selects tests to run by specifying a list of '
+                   'key=value pairs you wish to run'),
+            default=[], nargs='*')
 
     def generate_ascii_art(self):
         tag_line = _('Keeping the boogy man away from your code!')
@@ -50,8 +56,13 @@ class SpecterRunner(object):
         return ascii_art
 
     def run(self, args):
+        select_meta = None
         self.arguments = self.arg_parser.parse_args(args)
 
+        if self.arguments.select_meta:
+            metas = [meta.split('=') for meta in self.arguments.select_meta]
+            select_meta = {meta[0]: meta[1].strip('"\'') for meta in metas}
+
         if not self.arguments.no_art:
             print(self.generate_ascii_art())
 
@@ -75,8 +86,9 @@ class SpecterRunner(object):
                 self.coverage.start()
 
             suite = suite_type()
+            self.suites.append(suite)
             self.collector.add_describe(suite)
-            suite.execute()
+            suite.execute(select_metadata=select_meta)
 
             # Start Coverage Capture
             if self.coverage:
@@ -94,6 +106,10 @@ def activate(): #pragma: no cover
     args = sys.argv[1:]
     runner = SpecterRunner()
     runner.run(args)
+    # Return error code if tests fail
+    for suite in runner.suites:
+        if not suite.success:
+            exit(1)
 
 if __name__ == "__main__":
-    activate()
\ No newline at end of file
+    activate()
